.. CommonCrawl Extractor documentation master file, created by
   sphinx-quickstart on Tue Nov  8 17:40:35 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CommonCrawl Extractor's documentation!
=================================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation
   quickstart/index
   api






Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
